import React, { Component } from 'react'
import Modal from 'react-modal';
import ProductDetails from './product-details';
import '../../resources/stylesheets/product-market.css';

export default class ProductItem extends Component {
    constructor(props) {
        super(props)
        this.state = {
            orderItemQuantity: 0,
            showDetailsModal: false
        }
        this.handleSubmit = this.handleSubmit.bind(this);
        this.toggleDetailsModal = this.toggleDetailsModal.bind(this);
    }

    toggleDetailsModal() {
        const prevState = this.state.showDetailsModal;
        this.setState({ showDetailsModal: !prevState });
    }

    handleChange(type) {
        return e => {
            this.setState({ [type]: e.target.value })
        }
    }

    calculateDiscount(price, discount) {
        return (price * ((100 - discount) / 100)).toFixed(2);
    }

    handleSubmit(e, product) {
        e.preventDefault();
        // const newCart = Object.assign({}, this.props.cart);
        // const newCartItem = {
        //     productRef: {
        //         id: product.sku,
        //         sku: product.sku,
        //         upc: product.upc,
        //     },
        //     quantity: this.state.orderItemQuantity;
        // }
        // newCart.cartItems.push(newCartItem);
        // this.ptops.addCartItem(newCart);
    }
    
    render() {
        let discount = this.calculateDiscount(this.props.item.price, this.props.item.promo)
        return (
            <div className="product-item">
                <div id="more-details-img-box">
                    {
                        this.props.item.productImageUrl ? 
                        <img 
                            id="prod-img" 
                            alt="" 
                            src={ this.props.item.productImageUrl } 
                            onClick={ this.toggleDetailsModal }
                        />
                        :
                        <div 
                            id="no-image-found"
                            onClick={ this.toggleDetailsModal }
                        >
                            <p id="no-image-display">- No Photo Available -</p>
                        </div>
                    }
                    {
                        this.props.item.productImageUrl ?
                        <p onClick={ this.toggleDetailsModal } id="more-details-text">More Details</p>
                        : ""
                    }
                </div>
                <p id="prod-name">{ this.props.item.productName }</p>
                <div id="prod-price">
                    { this.props.item.promo ? 
                    <div id="promo-show">
                        <p id="promo-show-text-original">
                        ${ this.props.item.price }
                        </p>
                        <p id="promo-show-text">
                        ${ discount }
                        </p>
                    </div> : "$" + this.props.item.price }
                </div>
                { this.props.item.promo ?
                <p id="prod-promotion">
                    { "Save " + this.props.item.promo + "% on this item!"}
                </p> : ""}
                <form onSubmit={ e => this.handleSubmit(e, this.props.item) } className="add-cart-and-quantity">
                    <input 
                        className="order-quantity" 
                        type="number" 
                        placeholder="Qty"
                        onChange={ this.handleChange("orderItemQuantity") }
                    />
                    <button className="add-to-cart-button">Add to Cart</button>
                </form>

                <Modal
                    id="product-details-modal"
                    isOpen={ this.state.showDetailsModal }
                    contentLabel="Product Details Modal"
                    onRequestClose={ this.toggleDetailsModal }
                    style={{
                        content: {
                            top: '50%',
                            left: '50%',
                            right: '0',
                            bottom: '0',
                            marginLeft: "-325px",
                            marginTop: "-320px",
                            width: '650px',
                            height: '600px',
                            background: 'white',
                            borderRadius: "10px"
                        },
                        overlay: {
                            position: 'fixed',
                            backgroundColor: 'rgba(0,0,0,0.7)',
                            zIndex: '50'
                        }
                      }}
                >
                    <ProductDetails product={ this.props.item } discount={ discount } />
                </Modal>
            </div>
        )
    }
}
